@@ -4,11 +4,11 @@ describe 'basic ovn deployment' do
 
   context 'default parameters' do
     pp= <<-EOS
-    include ::openstack_integration
-    include ::openstack_integration::repos
+    include openstack_integration
+    include openstack_integration::repos
 
-    include ::ovn::northd
-    class { '::ovn::controller':
+    include ovn::northd
+    class { 'ovn::controller':
       ovn_remote   => 'tcp:127.0.0.1:6642',
       ovn_encap_ip => '127.0.0.1',
     }
@@ -20,9 +20,9 @@ describe 'basic ovn deployment' do
       apply_manifest(pp, :catch_changes => true)
     end
 
-    describe 'test openvswitch-ovn CLI' do
-      it 'list virtual ports' do
-        expect(shell('ovn-nbctl show').exit_code).to be_zero
+    it 'should show successfully' do
+      command('ovn-nbctl show') do |r|
+        expect(r.exit_code).to eq 0
       end
     end
   end
