@@ -3,14 +3,21 @@ require 'spec_helper'
 describe 'ovn::controller' do
 
   let :params do
-    { :ovn_remote                => 'tcp:x.x.x.x:5000',
-      :ovn_encap_type            => 'geneve',
-      :ovn_encap_ip              => '1.2.3.4',
-      :ovn_bridge_mappings       => ['physnet-1:br-1'],
-      :ovn_bridge                => 'br-int',
-      :bridge_interface_mappings => ['br-1:eth1'],
-      :hostname                  => 'server1.example.com',
-      :enable_hw_offload         => false
+    { :ovn_remote                  => 'tcp:x.x.x.x:5000',
+      :ovn_encap_type              => 'geneve',
+      :ovn_encap_ip                => '1.2.3.4',
+      :ovn_bridge_mappings         => ['physnet-1:br-1'],
+      :ovn_bridge                  => 'br-int',
+      :bridge_interface_mappings   => ['br-1:eth1'],
+      :hostname                    => 'server1.example.com',
+      :mac_table_size              => 20000,
+      :ovn_remote_probe_interval   => 30000,
+      :ovn_openflow_probe_interval => 8,
+      :ovn_monitor_all             => true,
+      :ovn_transport_zones         => ['tz1'],
+      :enable_ovn_match_northd     => false,
+      :ovn_chassis_mac_map         => ['physnet1:aa:bb:cc:dd:ee:ff',
+                                       'physnet2:bb:aa:cc:dd:ee:ff']
     }
   end
 
@@ -61,6 +68,29 @@ describe 'ovn::controller' do
       is_expected.to contain_vs_config('external_ids:ovn-bridge').with(
         :value   => params[:ovn_bridge],
       )
+
+      is_expected.to contain_vs_config('external_ids:ovn-remote-probe-interval').with(
+        :value   => params[:ovn_remote_probe_interval],
+      )
+
+      is_expected.to contain_vs_config('external_ids:ovn-openflow-probe-interval').with(
+        :value   => params[:ovn_openflow_probe_interval],
+      )
+
+      is_expected.to contain_vs_config('external_ids:ovn-monitor-all').with(
+        :value   => params[:ovn_monitor_all],
+      )
+
+      is_expected.to contain_vs_config('external_ids:ovn-transport-zones').with(
+        :value   => params[:ovn_transport_zones],
+      )
+
+      is_expected.to contain_vs_config('external_ids:ovn-match-northd-version').with(
+        :value   => params[:enable_ovn_match_northd],
+      )
+      is_expected.to contain_vs_config('external_ids:ovn-chassis-mac-mappings').with(
+        :value    => 'physnet1:aa:bb:cc:dd:ee:ff,physnet2:bb:aa:cc:dd:ee:ff',
+      )
     end
 
     it 'configures bridge mappings' do
@@ -78,6 +108,22 @@ describe 'ovn::controller' do
         :require => 'Service[openvswitch]'
       )
     end
+
+    context 'when ovn_chassis_mac_map is a hash' do
+      before :each do
+        params.merge!({
+          :ovn_chassis_mac_map => {
+            'physnet1' => 'aa:bb:cc:dd:ee:ff',
+            'physnet2' => 'bb:aa:cc:dd:ee:ff' }
+        })
+      end
+
+      it 'configures ovsdb' do
+        is_expected.to contain_vs_config('external_ids:ovn-chassis-mac-mappings').with(
+          :value    => 'physnet1:aa:bb:cc:dd:ee:ff,physnet2:bb:aa:cc:dd:ee:ff',
+        )
+      end
+    end
   end
 
   on_supported_os({
@@ -100,13 +146,13 @@ describe 'ovn::controller' do
           }
         end
         it_behaves_like 'ovn controller'
-      when 'Redhat'
+      when 'RedHat'
         let :platform_params do
           {
             :ovn_controller_package_name    => 'openvswitch-ovn-host',
             :ovn_controller_service_name    => 'ovn-controller',
             :ovn_controller_service_status  => true,
-            :ovn_controller_service_pattern => 'undef'
+            :ovn_controller_service_pattern => nil
           }
         end
         it_behaves_like 'ovn controller'
